==> verticalpodautoscaler-model-v1-6.7.1-sources.jar: io/fabric8/verticalpodautoscaler/api/model/v1/RecommendedContainerResourcesBuilder.java <==
package io.fabric8.verticalpodautoscaler.api.model.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class RecommendedContainerResourcesBuilder extends RecommendedContainerResourcesFluentImpl<RecommendedContainerResourcesBuilder> implements VisitableBuilder<RecommendedContainerResources,RecommendedContainerResourcesBuilder>{
  public RecommendedContainerResourcesBuilder() {
    this(false);
  }
  public RecommendedContainerResourcesBuilder(Boolean validationEnabled) {
    this(new RecommendedContainerResources(), validationEnabled);
  }
  public RecommendedContainerResourcesBuilder(RecommendedContainerResourcesFluent<?> fluent) {
    this(fluent, false);
  }
  public RecommendedContainerResourcesBuilder(RecommendedContainerResourcesFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new RecommendedContainerResources(), validationEnabled);
  }
  public RecommendedContainerResourcesBuilder(RecommendedContainerResourcesFluent<?> fluent,RecommendedContainerResources instance) {
    this(fluent, instance, false);
  }
  public RecommendedContainerResourcesBuilder(RecommendedContainerResourcesFluent<?> fluent,RecommendedContainerResources instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withContainerName(instance.getContainerName());
      fluent.withLowerBound(instance.getLowerBound());
      fluent.withTarget(instance.getTarget());
      fluent.withUncappedTarget(instance.getUncappedTarget());
      fluent.withUpperBound(instance.getUpperBound());
    }
    this.validationEnabled = validationEnabled; 
  }
  public RecommendedContainerResourcesBuilder(RecommendedContainerResources instance) {
    this(instance,false);
  }
  public RecommendedContainerResourcesBuilder(RecommendedContainerResources instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withContainerName(instance.getContainerName());
      this.withLowerBound(instance.getLowerBound());
      this.withTarget(instance.getTarget());
      this.withUncappedTarget(instance.getUncappedTarget());
      this.withUpperBound(instance.getUpperBound());
    }
    this.validationEnabled = validationEnabled; 
  }
  RecommendedContainerResourcesFluent<?> fluent;
  Boolean validationEnabled;
  public RecommendedContainerResources build() {
    RecommendedContainerResources buildable = new RecommendedContainerResources(fluent.getContainerName(),fluent.getLowerBound(),fluent.getTarget(),fluent.getUncappedTarget(),fluent.getUpperBound());
    return buildable;
  }
  
}

==> verticalpodautoscaler-model-v1-6.8.1-sources.jar: io/fabric8/verticalpodautoscaler/api/model/v1/RecommendedContainerResourcesBuilder.java <==
package io.fabric8.verticalpodautoscaler.api.model.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class RecommendedContainerResourcesBuilder extends RecommendedContainerResourcesFluent<RecommendedContainerResourcesBuilder> implements VisitableBuilder<RecommendedContainerResources,RecommendedContainerResourcesBuilder>{
  public RecommendedContainerResourcesBuilder() {
    this(false);
  }
  public RecommendedContainerResourcesBuilder(Boolean validationEnabled) {
    this(new RecommendedContainerResources(), validationEnabled);
  }
  public RecommendedContainerResourcesBuilder(RecommendedContainerResourcesFluent<?> fluent) {
    this(fluent, false);
  }
  public RecommendedContainerResourcesBuilder(RecommendedContainerResourcesFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new RecommendedContainerResources(), validationEnabled);
  }
  public RecommendedContainerResourcesBuilder(RecommendedContainerResourcesFluent<?> fluent,RecommendedContainerResources instance) {
    this(fluent, instance, false);
  }
  public RecommendedContainerResourcesBuilder(RecommendedContainerResourcesFluent<?> fluent,RecommendedContainerResources instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new RecommendedContainerResources());

    if (instance != null) {
      fluent.withContainerName(instance.getContainerName());
      fluent.withLowerBound(instance.getLowerBound());
      fluent.withTarget(instance.getTarget());
      fluent.withUncappedTarget(instance.getUncappedTarget());
      fluent.withUpperBound(instance.getUpperBound());
      fluent.withContainerName(instance.getContainerName());
      fluent.withLowerBound(instance.getLowerBound());
      fluent.withTarget(instance.getTarget());
      fluent.withUncappedTarget(instance.getUncappedTarget());
      fluent.withUpperBound(instance.getUpperBound());
    }
    this.validationEnabled = validationEnabled; 
  }
  public RecommendedContainerResourcesBuilder(RecommendedContainerResources instance) {
    this(instance,false);
  }
  public RecommendedContainerResourcesBuilder(RecommendedContainerResources instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new RecommendedContainerResources());

    if (instance != null) {
      this.withContainerName(instance.getContainerName());
      this.withLowerBound(instance.getLowerBound());
      this.withTarget(instance.getTarget());
      this.withUncappedTarget(instance.getUncappedTarget());
      this.withUpperBound(instance.getUpperBound());
      this.withContainerName(instance.getContainerName());
      this.withLowerBound(instance.getLowerBound());
      this.withTarget(instance.getTarget());
      this.withUncappedTarget(instance.getUncappedTarget());
      this.withUpperBound(instance.getUpperBound());
    }
    this.validationEnabled = validationEnabled; 
  }
  RecommendedContainerResourcesFluent<?> fluent;
  Boolean validationEnabled;
  public RecommendedContainerResources build() {
    RecommendedContainerResources buildable = new RecommendedContainerResources(fluent.getContainerName(),fluent.getLowerBound(),fluent.getTarget(),fluent.getUncappedTarget(),fluent.getUpperBound());
    return buildable;
  }
  
}
